@@ -137,7 +137,8 @@ class SelectedMethodWgt(qt.QWidget):
             selfsize = self.size()
             self.config.set('gui', 'size',
                 "{},{}".format(selfsize.width(), selfsize.height()))
-            self.config.write(open(self.user_config, 'w'))
+            with open(self.user_config, 'w') as f:
+                self.config.write(f)
         except (ConfigParser.NoOptionError, ConfigParser.NoSectionError):
             return False
 
@@ -569,7 +570,8 @@ class ToolTabWidget(qt.QTabWidget):
             selfsize = self.size()
             self.config.set('gui', 'size',
                 "{},{}".format(selfsize.width(), selfsize.height()))
-            self.config.write(open(self.user_config, 'w'))
+            with open(self.user_config, 'w') as f:
+                self.config.write(f)
         except (ConfigParser.NoOptionError, ConfigParser.NoSectionError):
             return False
 
