@@ -17,11 +17,11 @@
 import socket
 from calculate.consolegui import qt
 
-from more import LabelWordWrap, show_msg
+from more import LabelWordWrap, show_msg, get_icon
 
 def passphrase_callback(v):
     if type(v) == int or not v:
-        return None
+        return ""
     return str(v)
 
 def generateRSAKey():
@@ -128,7 +128,7 @@ class RequestCreate (qt.QWidget):
         self.setAttribute(qt.Qt.WA_DeleteOnClose)
         
         self.setWindowTitle (_('Create a signature request'))
-        self.setWindowIcon (qt.QIcon.fromTheme("view-certificate"))
+        self.setWindowIcon(get_icon("view-certificate"))
 
         self.setFocus()
         self.move(50+parent.frameGeometry().x(), \
@@ -147,12 +147,12 @@ class RequestCreate (qt.QWidget):
         private_key_passwd = self.passwd_lineedit.text()
         rsa = generateRSAKey()
         rsa.save_key(self.key + '_pub', cipher = None,
-                     callback = lambda *unused: None)
+                     callback = lambda *unused: "")
 
         pkey = makePKey(rsa)
         if not passphrase_callback(private_key_passwd):
             pkey.save_key(self.key, cipher = None,
-                          callback = lambda *unused: None)
+                          callback = lambda *unused: "")
         else:
             pkey.save_key(self.key,\
                             callback= lambda *unused: str(private_key_passwd))
@@ -175,7 +175,7 @@ class RequestCreate (qt.QWidget):
 #######
         req.set_subject_name(name)
 
-        ext1 = X509.new_extension('Comment', 'Auto Generated')
+        ext1 = X509.new_extension('nsComment', 'Auto Generated')
         extstack = X509.X509_Extension_Stack()
         extstack.push(ext1)
         req.add_extensions(extstack)
